@@ -25,6 +25,8 @@ class SerialCtrl : public ConnectionInterface {
   const std::auto_ptr<pImpl> pimpl;
 
 public:
+  enum { NoTimeout = -1 };
+
   explicit SerialCtrl(void);
   ~SerialCtrl(void);
 
@@ -35,8 +37,10 @@ public:
   int changeBaudrate(long baudrate);
   int send(const char* data, int size);
   int recv(char* data, int size, int timeout);
+  int getLine(std::string& data, int timeout);
   int size(void);
   void clear(void);
+  void skip(int timeout = NoTimeout);
 };
 
 #endif /* !SERIAL_CTRL_H */
